@@ -196,8 +196,8 @@ class ActivityNetDataset(BaseDataset):
                 Defaults: 'AR@AN'.
             max_avg_proposals (int): Max number of proposals to evaluate.
                 Defaults: 100.
-            temporal_iou_thresholds (list): Temporal IoU threshold for positive
-                samples. Defaults: np.linspace(0.5, 0.95, 10).
+            temporal_iou_thresholds (list | np.ndarray): Temporal IoU threshold
+                for positive samples. Defaults: np.linspace(0.5, 0.95, 10).
             logger (logging.Logger | None): Training logger. Defaults: None.
 
         Returns:
@@ -215,6 +215,9 @@ class ActivityNetDataset(BaseDataset):
             if metric not in allowed_metrics:
                 raise KeyError(f'metric {metric} is not supported')
 
+        if isinstance(temporal_iou_thresholds, list):
+            temporal_iou_thresholds = np.array(temporal_iou_thresholds)
+
         eval_results = {}
         ground_truth = self._import_ground_truth()
         proposal, num_proposals = self._import_proposals(results)
