@@ -1,13 +1,14 @@
 from .backbones import (ResNet, ResNet2Plus1d, ResNet3d, ResNet3dCSN,
                         ResNet3dSlowFast, ResNet3dSlowOnly, ResNetTIN,
                         ResNetTSM)
-from .builder import (build_backbone, build_head, build_localizer, build_model,
-                      build_recognizer)
+from .builder import (build_backbone, build_head, build_localizer, build_loss,
+                      build_model, build_neck, build_recognizer)
 from .common import Conv2plus1d
-from .heads import BaseHead, I3DHead, SlowFastHead, TSMHead, TSNHead
+from .heads import BaseHead, I3DHead, SlowFastHead, TPNHead, TSMHead, TSNHead
 from .localizers import BMN, PEM, TEM
 from .losses import (BCELossWithLogits, BinaryLogisticRegressionLoss, BMNLoss,
                      CrossEntropyLoss, NLLLoss, OHEMHingeLoss, SSNLoss)
+from .necks import TPN
 from .recognizers import BaseRecognizer, recognizer2d, recognizer3d
 from .registry import BACKBONES, HEADS, LOCALIZERS, LOSSES, RECOGNIZERS
 
@@ -19,5 +20,6 @@ __all__ = [
     'ResNet3dSlowFast', 'SlowFastHead', 'Conv2plus1d', 'ResNet3dSlowOnly',
     'BCELossWithLogits', 'LOCALIZERS', 'build_localizer', 'PEM', 'TEM',
     'BinaryLogisticRegressionLoss', 'BMN', 'BMNLoss', 'build_model',
-    'OHEMHingeLoss', 'SSNLoss', 'ResNet3dCSN', 'ResNetTIN'
+    'OHEMHingeLoss', 'SSNLoss', 'ResNet3dCSN', 'ResNetTIN', 'TPN', 'TPNHead',
+    'build_loss', 'build_neck'
 ]
