@@ -29,6 +29,8 @@ class BMN(BaseLocalizer):
         soft_nms_low_threshold (float): Soft NMS low threshold.
         soft_nms_high_threshold (float): Soft NMS high threshold.
         post_process_top_k (int): Top k proposals in post process.
+        feature_extraction_interval (int):
+            Interval used in feature extraction. Default: 16.
         loss_cls (dict): Config for building loss.
             Default: ``dict(type='BMNLoss')``.
         hidden_dim_1d (int): Hidden dim for 1d conv. Default: 256.
@@ -46,6 +48,7 @@ class BMN(BaseLocalizer):
                  soft_nms_low_threshold,
                  soft_nms_high_threshold,
                  post_process_top_k,
+                 feature_extraction_interval=16,
                  loss_cls=dict(type='BMNLoss'),
                  hidden_dim_1d=256,
                  hidden_dim_2d=128,
@@ -61,6 +64,7 @@ class BMN(BaseLocalizer):
         self.soft_nms_low_threshold = soft_nms_low_threshold
         self.soft_nms_high_threshold = soft_nms_high_threshold
         self.post_process_top_k = post_process_top_k
+        self.feature_extraction_interval = feature_extraction_interval
         self.loss_cls = build_loss(loss_cls)
         self.hidden_dim_1d = hidden_dim_1d
         self.hidden_dim_2d = hidden_dim_2d
@@ -260,7 +264,8 @@ class BMN(BaseLocalizer):
                                         self.soft_nms_alpha,
                                         self.soft_nms_low_threshold,
                                         self.soft_nms_high_threshold,
-                                        self.post_process_top_k)
+                                        self.post_process_top_k,
+                                        self.feature_extraction_interval)
         output = [
             dict(
                 video_name=video_info['video_name'],
