@@ -9,22 +9,32 @@ class Recognizer3D(BaseRecognizer):
     def forward_train(self, imgs, labels):
         """Defines the computation performed at every call when training."""
         imgs = imgs.reshape((-1, ) + imgs.shape[2:])
+        losses = dict()
 
         x = self.extract_feat(imgs)
+        if hasattr(self, 'neck'):
+            x, loss_aux = self.neck(x, labels.squeeze())
+            losses.update(loss_aux)
+
         cls_score = self.cls_head(x)
         gt_labels = labels.squeeze()
-        loss = self.cls_head.loss(cls_score, gt_labels)
+        loss_cls = self.cls_head.loss(cls_score, gt_labels)
+        losses.update(loss_cls)
 
-        return loss
+        return losses
 
     def forward_test(self, imgs):
         """Defines the computation performed at every call when evaluation and
         testing."""
+        num_segs = imgs.shape[1]
         imgs = imgs.reshape((-1, ) + imgs.shape[2:])
 
         x = self.extract_feat(imgs)
+        if hasattr(self, 'neck'):
+            x, _ = self.neck(x)
+
         cls_score = self.cls_head(x)
-        cls_score = self.average_clip(cls_score)
+        cls_score = self.average_clip(cls_score, num_segs)
 
         return cls_score.cpu().numpy()
 
